pub struct QueuedTaskInfo {
pub ptr: u64,
pub handler: u64,
pub initiating_dispatcher: u64,
pub initiating_dispatcher_name: String,
pub initiating_driver: u64,
pub initiating_driver_url: String,
}Expand description
Diagnostic information for a task queued on a dispatcher.
Fields
ptr: u64handler: u64initiating_dispatcher: u64initiating_dispatcher_name: Stringinitiating_driver: u64initiating_driver_url: StringTrait Implementations
Sourceimpl Clone for QueuedTaskInfo
impl Clone for QueuedTaskInfo
Sourcefn clone(&self) -> QueuedTaskInfo
fn clone(&self) -> QueuedTaskInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for QueuedTaskInfo
impl Debug for QueuedTaskInfo
Sourceimpl<D> Decode<QueuedTaskInfo, D> for QueuedTaskInfowhere
D: ResourceDialect,
impl<D> Decode<QueuedTaskInfo, D> for QueuedTaskInfowhere
D: ResourceDialect,
Sourcefn new_empty() -> QueuedTaskInfo
fn new_empty() -> QueuedTaskInfo
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<QueuedTaskInfo, D> for &QueuedTaskInfowhere
D: ResourceDialect,
impl<D> Encode<QueuedTaskInfo, D> for &QueuedTaskInfowhere
D: ResourceDialect,
impl Eq for QueuedTaskInfo
Sourceimpl Hash for QueuedTaskInfo
impl Hash for QueuedTaskInfo
Sourceimpl Ord for QueuedTaskInfo
impl Ord for QueuedTaskInfo
Sourcefn cmp(&self, other: &QueuedTaskInfo) -> Ordering
fn cmp(&self, other: &QueuedTaskInfo) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for QueuedTaskInfo
impl PartialEq for QueuedTaskInfo
Sourceimpl PartialOrd for QueuedTaskInfo
impl PartialOrd for QueuedTaskInfo
impl Persistable for QueuedTaskInfo
impl StructuralPartialEq for QueuedTaskInfo
Sourceimpl TypeMarker for QueuedTaskInfo
impl TypeMarker for QueuedTaskInfo
Sourcetype Owned = QueuedTaskInfo
type Owned = QueuedTaskInfo
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for QueuedTaskInfo
impl ValueTypeMarker for QueuedTaskInfo
Sourcetype Borrowed<'a> = &'a QueuedTaskInfo
type Borrowed<'a> = &'a QueuedTaskInfo
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<QueuedTaskInfo as TypeMarker>::Owned,
) -> <QueuedTaskInfo as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<QueuedTaskInfo as TypeMarker>::Owned, ) -> <QueuedTaskInfo as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for QueuedTaskInfo
impl RefUnwindSafe for QueuedTaskInfo
impl Send for QueuedTaskInfo
impl Sync for QueuedTaskInfo
impl Unpin for QueuedTaskInfo
impl UnsafeUnpin for QueuedTaskInfo
impl UnwindSafe for QueuedTaskInfo